//! TODO(doc): @quake

// num_cpus is used in proc_macro
pub mod shared;

pub use ckb_snapshot::{Snapshot, SnapshotMgr};
pub use shared::Shared;
